
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

###########################
Sample usage for dependency
###########################

.. include:: ../../nltk/test/dependency.doctest